#####
#
# CB
# 2019-05-22
#
#####


library(dplyr)


### Set the working path to this R-project
path <- paste0(getwd(),"/")


### load some parameter
# Management regimes and their abbreviation 
regime <- read.csv(paste0(path, "params/regimes.csv"), sep = ",", stringsAsFactors = FALSE)


### Simulation variant
# specify which one:  "CC45" climate change with RCP scenraio 4.5 
#                     "CC85" climate change with RCP scenario 8.5 
#                     "without" no climate change
sim_variant <- "without"  


### Define the names of the SQL databases (SIMO-output) that will imported
# It is used in the skripts "structure_SIMO_rslDB_FBE.R" and "loadDB.R"
db_names <- c("MV_Hartola", 
              "MV_Kitee", 
              "MV_Korsnas", 
              "MV_Parikkala",
              "MV_Pori",
              "MV_Pyhtaa",
              "MV_Raasepori",
              "MV_Simo",
              "MV_Vaala",
              "MV_Voyri")


### Restructure the SQL database: querry that creates the final UNIT table, which contains indicators over time under regimes
#
# !!! Only needed if the DB is read/loaded for the first time.  !!!

source(paste0(path, "structure_SIMO_rslDB_FBE.R")) # Afterwards, you can exclude this line with: #


### Import the restructured SIMO data (from UNIT table) in the R-environment
# It gives a single dataframe for each database named by "rsl_db_names.csv" AND an overall dataframe called "rslt_all.csv"
# Select columns that should be importat from the SQL table UNIT (created before by script structure_SIMO_rslDB)
# An overview on all available SIMO outcomes can be found under: params/Overview_outcomes_SIMO.xlsx

columns <-  paste0("id,
                   year,
                   branch,
                   branch_desc,
                   branching_group,
                   Age,
                   area,
                   cash_flow,
                   V_total_deadwood,
                   BA,
                   V,
                   N,
                   H_dom,
                   D_gm,
                   Harvested_V,
                   Biomass,
                   income_biomass,
                   CARBON_STORAGE")


### !!! Needed if the DB is read/loaded for the first time, since dataframes are also stored as csv-file under "output/".  !!!

source(paste0(path, "loadDB.R")) # Afterwards, you can also exclude this line with: #

# ... and the single csv can later also be loaded into the R-environment with:

# rslt <- read.csv(paste0(path, "output/rslt_", sim_variant, "_all.csv" ), sep = ";", header = TRUE, stringsAsFactors = FALSE)



